@@ -457,7 +457,7 @@ class TeX:
 
         return labels
 
-    def _reformat(self, label: str, key: str):
+    def _reformat(self, label: str, key: str, prefix: str = None):
         """
         Reformat labels (and references) to f"{key}:{label}" (if needed).
         Suppose that the target is "fig:foo", this function also converts
@@ -465,22 +465,28 @@ class TeX:
 
         :param label: The label (with or without ``key:``).
         :param key: The 'keyword' to add/ensure.
+        :param prefix: Add optional ``prefix`. E.g. ``key:prefix:...``.
         """
 
-        if re.match(f"({key}:)(.*)", label, re.IGNORECASE):
-            info = re.split(re.compile(f"({key}:)(.*)", re.IGNORECASE), label)[2]
-            return f"{key}:{info}"
+        ret = f"{key}"
 
-        if re.match(f"({key})(-)(.*)", label, re.IGNORECASE):
-            info = re.split(re.compile(f"({key})(-)(.*)", re.IGNORECASE), label)[3]
-            return f"{key}:{info}"
+        if prefix is not None:
 
-        if re.match(f"({key})(_)(.*)", label, re.IGNORECASE):
-            info = re.split(re.compile(f"({key})(_)(.*)", re.IGNORECASE), label)[3]
-            return f"{key}:{info}"
+            ret = f"{key}:{prefix}"
 
-        if not re.match(key + ":.*", label, re.IGNORECASE):
-            return f"{key}:{label}"
+            for sep in [":", "-", "_"]:
+                regex = re.compile(f"({key})({sep})({prefix})({sep})(.*)", re.IGNORECASE)
+                if re.match(regex, label):
+                    info = re.split(regex, label)[-2]
+                    return f"{ret}:{info}"
+
+        for sep in [":", "-", "_"]:
+            regex = re.compile(f"({key})({sep})(.*)", re.IGNORECASE)
+            if re.match(regex, label):
+                info = re.split(regex, label)[-2]
+                return f"{ret}:{info}"
+
+        return f"{ret}:{label}"
 
     def _environment_index(self, envs: list[str], iden: dict) -> dict:
         """
@@ -550,7 +556,7 @@ class TeX:
 
         return list(set(ret))
 
-    def format_labels(self):
+    def format_labels(self, prefix: str = None):
         """
         Format all labels as:
         *   ``sec:...``: Section labels.
@@ -558,6 +564,8 @@ class TeX:
         *   ``fig:...``: Figure labels.
         *   ``tab:...``: Table labels.
         *   ``eq:...``: Math labels.
+
+        :param prefix: Add optional ``prefix`. E.g. ``key:prefix:...``.
         """
 
         iden = {
@@ -596,7 +604,7 @@ class TeX:
             for key in envs:
                 c = np.logical_and(envs[key][:, 0] < ilab, envs[key][:, 1] > ilab)
                 if np.any(c):
-                    change[label] = self._reformat(label, key)
+                    change[label] = self._reformat(label, key, prefix=prefix)
                     stop = True
                     break
 
@@ -605,10 +613,12 @@ class TeX:
 
             for h in headers:
                 test = ilab > headers[h]
+                if not np.any(test):
+                    continue
                 i = test.size - 1 if np.all(test) else np.argmin(test) - 1
                 start = headers[h][i] + 1
                 if re.match(r"([\s\n%]*)(\\label{)", self.main[start:]):
-                    change[label] = self._reformat(label, iden[h])
+                    change[label] = self._reformat(label, iden[h], prefix=prefix)
                     stop = True
                     break
 
@@ -713,46 +723,85 @@ def _texcleanup_parser():
     Return parser for :py:func:`texcleanup`.
     """
 
-    h = textwrap.dedent(
-        r"""Apply some simple clean-up rules.
-        Most of the options are fully self explanatory. A word it need about "--replace-command":
-        It can replace a command by another command, or simply 'remove' it, keeping just a sequence
-        of arguments. This option is very much like a LaTeX command, but applied to the source.
-        For example::
+    parser = argparse.ArgumentParser(
+        formatter_class=argparse.RawTextHelpFormatter,
+        description=textwrap.dedent(
+            """\
+            Apply some simple clean-up rules.
+            Most of the options are fully self explanatory, except for:
 
-            --replace-command r"{\TG}[2]" "#1"
+            --replace-command
+                It can replace a command by another command, or simply 'remove' it,
+                keeping just a sequence of arguments.
+                This option is very much like a LaTeX command, but applied to the source.
+                For example::
 
-        Applied a change as follows::
+                    --replace-command "{\\TG}[2]" "#1"
 
-            >>> This is a \TG{text}{test}.
-            <<< This is a test.
+                Applied a change as follows::
 
-        Note that the number of arguments, e.g. [2], defaults to one if not specified.
-        """
+                    >>> This is a \\TG{text}{test}.
+                    <<< This is a test.
+
+                Note that the number of arguments, ``[2]`` above, defaults to ``1``.
+            """
+        ),
     )
-    parser = argparse.ArgumentParser(description=h)
 
-    h = "Remove lines that have only comments"
-    parser.add_argument("--remove-commentlines", action="store_true", help=h)
-
-    h = "Remove all comments"
-    parser.add_argument("--remove-comments", action="store_true", help=h)
-
-    h = "Replace command (see above)"
     parser.add_argument(
-        "--replace-command", type=str, nargs=2, action="append", metavar=("cmd", "def"), help=h
+        "-c",
+        "--remove-commentlines",
+        action="store_true",
+        help="Remove all lines that have only comments (excluding preamble).",
     )
 
-    h = "Change label"
     parser.add_argument(
-        "--change-label", type=str, nargs=2, action="append", metavar=("old", "new"), help=h
+        "-C",
+        "--remove-comments",
+        action="store_true",
+        help="Remove all comments (excluding preamble).",
     )
 
-    h = 'Add "fig:", "eq:", "tab:", "sec:", "ch:" to labels'
-    parser.add_argument("--format-labels", action="store_true", help=h)
+    parser.add_argument(
+        "-r",
+        "--replace-command",
+        type=str,
+        nargs=2,
+        action="append",
+        metavar=("cmd", "def"),
+        help="Replace command (see above).",
+    )
 
-    h = r'Change "Fig.~\ref{...}" etc. to "\cref{...}"'
-    parser.add_argument("--use-cleveref", action="store_true", help=h)
+    parser.add_argument(
+        "-l",
+        "--change-label",
+        type=str,
+        nargs=2,
+        action="append",
+        metavar=("old", "new"),
+        help="Rename a specific label.",
+    )
+
+    parser.add_argument(
+        "-f",
+        "--format-labels",
+        action="store_true",
+        help='Automatically prepend labels with "fig:", "eq:", "tab:", "sec:", "ch:" (if needed).',
+    )
+
+    parser.add_argument(
+        "-F",
+        "--prepend-format-labels",
+        type=str,
+        help='Automatically prepend labels with "fig:ARG", "eq:ARG", ...; see --format-labels.',
+    )
+
+    parser.add_argument(
+        "-s",
+        "--use-cleveref",
+        action="store_true",
+        help=r'Change "Fig.~\ref{...}" etc. to "\\cref{...}".',
+    )
 
     parser.add_argument("-v", "--version", action="version", version=version)
     parser.add_argument("files", nargs="+", type=str, help="TeX file")
@@ -790,6 +839,9 @@ def texcleanup(args: list[str]):
         if args.format_labels:
             tex.format_labels()
 
+        if args.prepend_format_labels:
+            tex.format_labels(args.prepend_format_labels)
+
         if args.use_cleveref:
             tex.use_cleveref()
 
